summaryrefslogtreecommitdiffstats
path: root/libpostproc/postprocess.c
diff options
context:
space:
mode:
Diffstat (limited to 'libpostproc/postprocess.c')
-rw-r--r--libpostproc/postprocess.c21
1 files changed, 13 insertions, 8 deletions
diff --git a/libpostproc/postprocess.c b/libpostproc/postprocess.c
index c363fa7..ed5c240 100644
--- a/libpostproc/postprocess.c
+++ b/libpostproc/postprocess.c
@@ -3,20 +3,20 @@
*
* AltiVec optimizations (C) 2004 Romain Dolbeau <romain@dolbeau.org>
*
* This file is part of Libav.
*
* Libav is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* Libav is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with Libav; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
@@ -75,6 +75,7 @@ try to unroll inner for(x=0 ... loop to avoid these damn if(x ... checks
#include "config.h"
#include "libavutil/avutil.h"
+#include "libavutil/avassert.h"
#include <inttypes.h>
#include <stdio.h>
#include <stdlib.h>
@@ -90,18 +91,19 @@ try to unroll inner for(x=0 ... loop to avoid these damn if(x ... checks
unsigned postproc_version(void)
{
+ av_assert0(LIBPOSTPROC_VERSION_MICRO >= 100);
return LIBPOSTPROC_VERSION_INT;
}
const char *postproc_configuration(void)
{
- return LIBAV_CONFIGURATION;
+ return FFMPEG_CONFIGURATION;
}
const char *postproc_license(void)
{
#define LICENSE_PREFIX "libpostproc license: "
- return LICENSE_PREFIX LIBAV_LICENSE + sizeof(LICENSE_PREFIX) - 1;
+ return LICENSE_PREFIX FFMPEG_LICENSE + sizeof(LICENSE_PREFIX) - 1;
}
#if HAVE_ALTIVEC_H
@@ -664,7 +666,11 @@ static inline void postProcess(const uint8_t src[], int srcStride, uint8_t dst[]
/* -pp Command line Help
*/
+#if LIBPOSTPROC_VERSION_INT < (52<<16)
+const char *const pp_help=
+#else
const char pp_help[] =
+#endif
"Available postprocessing filters:\n"
"Filters Options\n"
"short long name short long option Description\n"
@@ -783,8 +789,7 @@ pp_mode *pp_get_mode_by_name_and_quality(const char *name, int quality)
int plen;
int spaceLeft;
- if(p==NULL) p= temp, *p=0; //last filter
- else p--, *p=','; //not last filter
+ p--, *p=',';
plen= strlen(p);
spaceLeft= p - temp + plen;
OpenPOWER on IntegriCloud
@@ -3,20 +3,20 @@
* AltiVec optimizations (C) 2004 Romain Dolbeau <romain@dolbeau.org>
*
- * This file is part of Libav.
+ * This file is part of FFmpeg.
*
@@ -3,20 +3,20 @@
*
- * Libav is free software; you can redistribute it and/or modify
+ * FFmpeg is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -3,20 +3,20 @@
* (at your option) any later version.
*
- * Libav is distributed in the hope that it will be useful,
+ * FFmpeg is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -3,20 +3,20 @@
*
* You should have received a copy of the GNU General Public License
- * along with Libav; if not, write to the Free Software
+ * along with FFmpeg; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/